Package: ocsinventory-agent
Version: 1:0.0.9.2repack1-3
Severity: normal
Tags: patch

--- Please enter the report below this line. ---
--nosoftware option has no effect and give a warning     Private: (?)
No
[EMAIL PROTECTED]:~$ ocsinventory-agent -l /tmp --nosoftware
[info] the parameter --nosoft is deprecated and may be removed in a futur
release, please use --nosoftware instead.
[info] Inventory saved in /tmp/Trash-laptop-2008-08-05-10-21-06.ocs

--nosoftware option has no effect and give a warning


[EMAIL PROTECTED]:~$ ocsinventory-agent -l /tmp --nosoft
[info] Inventory saved in /tmp/Trash-laptop-2008-08-05-10-21-06.ocs

works correctly


The problem is reported upstream here : 
http://sourceforge.net/tracker/index.php?func=detail&aid=2091166&group_id=58373&atid=487492
and is fixed on the CVS repository (it was fixed before I reported it). 

In attachment you can find a patch to fix the problem on 0.9.2. 

--- System information. ---
Architecture: i386
Kernel:       Linux 2.6.26-1-686

Debian Release: lenny/sid
 1001 testing         security.debian.org 
 1001 testing         ftp.fr.debian.org 

--- Package information. ---
Depends                       (Version) | Installed
=======================================-+-==============
debconf                       (>= 0.5)  | 1.5.22
 OR debconf-2.0                         | 
perl                      (>= 5.6.0-16) | 5.10.0-13
po-debconf                              | 1.0.15
ucf                                     | 3.007
libxml-simple-perl                      | 2.18-1
libnet-ip-perl                          | 1.25-2
libcompress-zlib-perl                   | 2.012-1
libwww-perl                             | 5.813-1
libnet-ssleay-perl                      | 1.35-1
libproc-daemon-perl                     | 0.03-2

-- 
Laurent Léonard
diff -Nru Ocsinventory-Agent-0.0.9.2/ocsinventory-agent Ocsinventory-Agent-0.0.9.2-nosoftware/ocsinventory-agent
--- Ocsinventory-Agent-0.0.9.2/ocsinventory-agent	2008-04-18 18:49:44.000000000 +0200
+++ Ocsinventory-Agent-0.0.9.2-nosoftware/ocsinventory-agent	2008-09-03 15:24:25.000000000 +0200
@@ -210,7 +210,7 @@
 
   });
 
-if ($params->{nosoftware}) {
+if ($params->{nosoft}) {
     $logger->info("the parameter --nosoft is deprecated and may be removed in a futur release, please use --nosoftware instead.");
     $params->{nosoftware} = 1 
 }

Attachment: signature.asc
Description: This is a digitally signed message part.

Reply via email to
diff -Nru Ocsinventory-Agent-0.0.9.2/lib/Ocsinventory/Agent/Backend/OS/AIX/Software.pm Ocsinventory-Agent-0.0.9.2-nosoftware/lib/Ocsinventory/Agent/Backend/OS/AIX/Software.pm
--- Ocsinventory-Agent-0.0.9.2/lib/Ocsinventory/Agent/Backend/OS/AIX/Software.pm	2008-04-02 17:33:20.000000000 +0200
+++ Ocsinventory-Agent-0.0.9.2-nosoftware/lib/Ocsinventory/Agent/Backend/OS/AIX/Software.pm	2008-09-03 15:15:05.000000000 +0200
@@ -6,8 +6,8 @@
 sub check {
   my $params = shift;
 
-  # Do not run an package inventory if there is the --nosoft parameter
-  return if ($params->{params}->{nosoft});
+  # Do not run an package inventory if there is the --nosoftware parameter
+  return if ($params->{params}->{nosoftware});
 
   `lslpp -l 2>&1`;
   return if ($? >> 8)!=0;
diff -Nru Ocsinventory-Agent-0.0.9.2/lib/Ocsinventory/Agent/Backend/OS/Generic/Packaging.pm Ocsinventory-Agent-0.0.9.2-nosoftware/lib/Ocsinventory/Agent/Backend/OS/Generic/Packaging.pm
--- Ocsinventory-Agent-0.0.9.2/lib/Ocsinventory/Agent/Backend/OS/Generic/Packaging.pm	2008-04-02 17:33:20.000000000 +0200
+++ Ocsinventory-Agent-0.0.9.2-nosoftware/lib/Ocsinventory/Agent/Backend/OS/Generic/Packaging.pm	2008-09-03 15:15:18.000000000 +0200
@@ -5,8 +5,8 @@
 sub check {
   my $params = shift;
   
-  # Do not run an package inventory if there is the --nosoft parameter
-  return if ($params->{params}->{nosoft});
+  # Do not run an package inventory if there is the --nosoftware parameter
+  return if ($params->{params}->{nosoftware});
    
   1;
 }
diff -Nru Ocsinventory-Agent-0.0.9.2/lib/Ocsinventory/Agent/Backend/OS/Solaris/Packages.pm Ocsinventory-Agent-0.0.9.2-nosoftware/lib/Ocsinventory/Agent/Backend/OS/Solaris/Packages.pm
--- Ocsinventory-Agent-0.0.9.2/lib/Ocsinventory/Agent/Backend/OS/Solaris/Packages.pm	2008-04-02 17:33:20.000000000 +0200
+++ Ocsinventory-Agent-0.0.9.2-nosoftware/lib/Ocsinventory/Agent/Backend/OS/Solaris/Packages.pm	2008-09-03 15:15:33.000000000 +0200
@@ -6,8 +6,8 @@
 sub check {
   my $params = shift;
 
-  # Do not run an package inventory if there is the --nosoft parameter
-  return if ($params->{params}->{nosoft});
+  # Do not run an package inventory if there is the --nosoftware parameter
+  return if ($params->{params}->{nosoftware});
 
   `which pkginfo 2>&1`;
   return if ($? >> 8)!=0;